package de.jg_cody.Teraplex.ui.Einstellungen;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.SharedPreferences;
import android.content.res.Configuration;
import android.graphics.BitmapFactory;
import android.graphics.drawable.BitmapDrawable;
import android.os.Build;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.annotation.RequiresApi;
import androidx.fragment.app.Fragment;
import androidx.lifecycle.ViewModelProvider;

import com.rarepebble.colorpicker.ColorPickerView;

import java.util.Base64;
import java.util.Locale;

import de.jg_cody.Teraplex.MainActivity;
import de.jg_cody.Teraplex.R;

import static android.content.Context.MODE_PRIVATE;

public class EinstellungenFragment extends Fragment {

    private EinstellungenViewModel einstellungenViewModel;
    Button button_colorpicker;

    @RequiresApi(api = Build.VERSION_CODES.O)
    public View onCreateView(@NonNull LayoutInflater inflater,
                             ViewGroup container, Bundle savedInstanceState) {
        einstellungenViewModel =
                new ViewModelProvider(this).get(EinstellungenViewModel.class);
        View root = inflater.inflate(R.layout.fragment_einstellungen, container, false);
        SharedPreferences p = getContext().getSharedPreferences("appsettings", Activity.MODE_PRIVATE);
        String Background = p.getString("Background", null);
        if (Background != null) {
            ImageView I = root.findViewById(R.id.Background);
            byte[] BA = Base64.getDecoder().decode(Background);
            I.setImageDrawable(new BitmapDrawable(getResources(), MainActivity.scaleCenterCrop(BitmapFactory.decodeByteArray(BA, 0, BA.length), MainActivity.getScreenHeight(), MainActivity.getScreenWidth())));
            I.setScaleType(ImageView.ScaleType.CENTER_CROP);
        }
        button_colorpicker = (Button) root.findViewById(R.id.button_colorpicker);
        button_colorpicker.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {

                try {
                    Toast.makeText(getContext(), "Colorpicker", Toast.LENGTH_SHORT).show();
                    final ColorPickerView picker = new ColorPickerView(getContext());
                    picker.setColor(0xff12345);
                    AlertDialog mDialog = new AlertDialog.Builder(getContext()).setView(picker).setTitle(R.string.colorpicker).setPositiveButton(R.string.ok, new DialogInterface.OnClickListener() {
                        @Override
                        public void onClick(DialogInterface dialog, int which) {

                        }
                    }).create();
                    mDialog.getWindow().setBackgroundDrawableResource(R.drawable.button_round);
                    mDialog.show();
                } catch (Exception e) {
                }
            }
        });
        Button Language = root.findViewById(R.id.button_language);
        Language.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                showChangeLanguageDialog();

            }
        });
        Button Reset = root.findViewById(R.id.button_reset);
        Reset.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {

                AlertDialog mDialog = new AlertDialog.Builder(getContext())
                        .setTitle(R.string.reset_app)
                        .setMessage(R.string.are_you_sure_to_reset)

                        // Specifying a listener allows you to take an action before dismissing the dialog.
                        // The dialog is automatically dismissed when a dialog button is clicked.
                        .setPositiveButton(android.R.string.yes, new DialogInterface.OnClickListener() {
                            public void onClick(DialogInterface dialog, int which) {
                                try {
                                    getContext().getSharedPreferences("appsettings", Context.MODE_PRIVATE).edit().clear().commit();
                                    startActivity(getActivity().getIntent());
                                    getActivity().finish();
                                } catch (Exception e) {
                                }

                                // Continue with delete operation
                            }
                        })

                        // A null listener allows the button to dismiss the dialog and take no further action.
                        .setNegativeButton(android.R.string.no, null)
                        .create();
                mDialog.getWindow().setBackgroundDrawableResource(R.drawable.button_round);
                mDialog.show();
            }

        });
        Button choose_background = root.findViewById(R.id.button_pickimage);
        choose_background.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                Intent i = new Intent(
                        Intent.ACTION_PICK, android.provider.MediaStore.Images.Media.EXTERNAL_CONTENT_URI);
                getActivity().startActivityForResult(i, MainActivity.RESULT_LOAD_IMAGE);

            }
        });


        return root;
    }

    private void showChangeLanguageDialog() {
        final String[] listItems = {"GERMAN", "ENGLISCH", "KLINGONISCH"};
        AlertDialog.Builder mBuilder = new AlertDialog.Builder(getContext());
        mBuilder.setTitle("CHOOSE LANGUAGE");
        mBuilder.setSingleChoiceItems(listItems, -5, new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialogInterface, int i) {
                if (i == 0) {
                    setLocale("de");
                    startActivity(getActivity().getIntent());
                    getActivity().finish();
                } else if (i == 1) {
                    setLocale("en");
                    startActivity(getActivity().getIntent());
                    getActivity().finish();
                } else if (i == 2) {
                    setLocale("tlh");
                    startActivity(getActivity().getIntent());
                    getActivity().finish();
                }
                dialogInterface.dismiss();
            }
        });
        AlertDialog mDialog = mBuilder.create();
        mDialog.getWindow().setBackgroundDrawableResource(R.drawable.button_round);
        mDialog.show();
    }

    private void setLocale(String lang) {
        Locale locale = new Locale(lang);
        Locale.setDefault(locale);
        Configuration config = new Configuration();
        config.locale = locale;
        getContext().getResources().updateConfiguration(config, getContext().getResources().getDisplayMetrics());
        SharedPreferences.Editor editor = getContext().getSharedPreferences("appsettings", MODE_PRIVATE).edit();
        editor.putString("Language", lang);
        editor.apply();
    }
}